@@ -28,30 +28,16 @@ pip install cloudcomponents.cdk-blue-green-container-deployment
 ## How to use
 
 ```python
-import { Construct, Duration, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Pipeline, Artifact } from '@aws-cdk/aws-codepipeline';
-import { Vpc, Port } from '@aws-cdk/aws-ec2';
-import { Cluster } from '@aws-cdk/aws-ecs';
-import {
-  ApplicationLoadBalancer,
-  ApplicationTargetGroup,
-  TargetType,
-} from '@aws-cdk/aws-elasticloadbalancingv2';
-import {
-  CodeBuildAction,
-  CodeCommitSourceAction,
-  CodeDeployEcsDeployAction,
-} from '@aws-cdk/aws-codepipeline-actions';
-
+import { EcsService, DummyTaskDefinition, EcsDeploymentGroup, PushImageProject } from '@cloudcomponents/cdk-blue-green-container-deployment';
 import { ImageRepository } from '@cloudcomponents/cdk-container-registry';
-import {
-  EcsService,
-  DummyTaskDefinition,
-  EcsDeploymentConfig,
-  EcsDeploymentGroup,
-  PushImageProject,
-} from '@cloudcomponents/cdk-blue-green-container-deployment';
+import { Duration, Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Pipeline, Artifact } from 'aws-cdk-lib/aws-codepipeline';
+import { CodeBuildAction, CodeCommitSourceAction, CodeDeployEcsDeployAction } from 'aws-cdk-lib/aws-codepipeline-actions';
+import { Vpc, Port } from 'aws-cdk-lib/aws-ec2';
+import { Cluster } from 'aws-cdk-lib/aws-ecs';
+import { ApplicationLoadBalancer, ApplicationTargetGroup, TargetType } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
+import { Construct } from 'constructs';
 
 export class BlueGreenContainerDeploymentStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -71,7 +57,7 @@ export class BlueGreenContainerDeploymentStack extends Stack {
       internetFacing: true,
     });
 
-    const prodListener = loadBalancer.addListener('ProdListener', {
+    const prodListener = loadBalancer.addListener('ProfListener', {
       port: 80,
     });
 
@@ -79,43 +65,31 @@ export class BlueGreenContainerDeploymentStack extends Stack {
       port: 8080,
     });
 
-    const prodTargetGroup = new ApplicationTargetGroup(
-      this,
-      'ProdTargetGroup',
-      {
-        port: 80,
-        targetType: TargetType.IP,
-        vpc,
-      },
-    );
+    const prodTargetGroup = new ApplicationTargetGroup(this, 'ProdTargetGroup', {
+      port: 80,
+      targetType: TargetType.IP,
+      vpc,
+    });
 
     prodListener.addTargetGroups('AddProdTg', {
       targetGroups: [prodTargetGroup],
     });
 
-    const testTargetGroup = new ApplicationTargetGroup(
-      this,
-      'TestTargetGroup',
-      {
-        port: 8080,
-        targetType: TargetType.IP,
-        vpc,
-      },
-    );
+    const testTargetGroup = new ApplicationTargetGroup(this, 'TestTargetGroup', {
+      port: 8080,
+      targetType: TargetType.IP,
+      vpc,
+    });
 
     testListener.addTargetGroups('AddTestTg', {
       targetGroups: [testTargetGroup],
     });
 
     // Will be replaced by CodeDeploy in CodePipeline
-    const taskDefinition = new DummyTaskDefinition(
-      this,
-      'DummyTaskDefinition',
-      {
-        image: 'nginx',
-        family: 'blue-green',
-      },
-    );
+    const taskDefinition = new DummyTaskDefinition(this, 'DummyTaskDefinition', {
+      image: 'nginx',
+      family: 'blue-green',
+    });
 
     const ecsService = new EcsService(this, 'EcsService', {
       cluster,
@@ -129,21 +103,6 @@ export class BlueGreenContainerDeploymentStack extends Stack {
     ecsService.connections.allowFrom(loadBalancer, Port.tcp(80));
     ecsService.connections.allowFrom(loadBalancer, Port.tcp(8080));
 
-    const deploymentConfig = new EcsDeploymentConfig(
-      this,
-      'DeploymentConfig',
-      {
-        deploymentConfigName: 'Canary20Percent5Minute',
-        trafficRoutingConfig: {
-          type: 'TimeBasedCanary',
-          timeBasedCanary: {
-            canaryInterval: 5,
-            canaryPercentage: 20,
-          },
-        },
-      }
-    );
-
     const deploymentGroup = new EcsDeploymentGroup(this, 'DeploymentGroup', {
       applicationName: 'blue-green-application',
       deploymentGroupName: 'blue-green-deployment-group',
@@ -152,10 +111,9 @@ export class BlueGreenContainerDeploymentStack extends Stack {
       prodTrafficListener: prodListener,
       testTrafficListener: testListener,
       terminationWaitTime: Duration.minutes(100),
-      deploymentConfig, // If you want to use default DeploymentConfig name, use static method as "EcsDeploymentConfig.CANARY_10PERCENT_15MINUTES".
     });
 
-    // @see https://github.com/cloudcomponents/cdk-constructs/tree/master/examples/blue-green-container-deployment-example/blue-green-repository
+    // @see files: ./blue-green-repository for example content
     const repository = new Repository(this, 'CodeRepository', {
       repositoryName: 'blue-green-repository',
     });
@@ -245,6 +203,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_codebuild
 import aws_cdk.aws_codedeploy
 import aws_cdk.aws_ec2
@@ -252,7 +211,7 @@ import aws_cdk.aws_ecr
 import aws_cdk.aws_ecs
 import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_iam
-import aws_cdk.core
+import constructs
 
 
 @jsii.data_type(
@@ -351,8 +310,8 @@ class EcsDeploymentConfigurationProps:
         self,
         *,
         deployment_config_name: typing.Optional[builtins.str] = None,
-        minimum_healthy_hosts: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.core.IResolvable]] = None,
-        traffic_routing_config: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty]] = None,
+        minimum_healthy_hosts: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.IResolvable]] = None,
+        traffic_routing_config: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty, aws_cdk.IResolvable]] = None,
     ) -> None:
         '''
         :param deployment_config_name: ``AWS::CodeDeploy::DeploymentConfig.DeploymentConfigName``.
@@ -380,26 +339,26 @@ class EcsDeploymentConfigurationProps:
     @builtins.property
     def minimum_healthy_hosts(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.IResolvable]]:
         '''``AWS::CodeDeploy::DeploymentConfig.MinimumHealthyHosts``.
 
         :external: true
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codedeploy-deploymentconfig.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts
         '''
         result = self._values.get("minimum_healthy_hosts")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.IResolvable]], result)
 
     @builtins.property
     def traffic_routing_config(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty, aws_cdk.IResolvable]]:
         '''``AWS::CodeDeploy::DeploymentConfig.TrafficRoutingConfig``.
 
         :external: true
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codedeploy-deploymentconfig.html#cfn-codedeploy-deploymentconfig-trafficroutingconfig
         '''
         result = self._values.get("traffic_routing_config")
-        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty]], result)
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty, aws_cdk.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -422,6 +381,7 @@ class EcsDeploymentConfigurationProps:
         "prod_traffic_listener": "prodTrafficListener",
         "target_groups": "targetGroups",
         "test_traffic_listener": "testTrafficListener",
+        "application": "application",
         "application_name": "applicationName",
         "auto_rollback_on_events": "autoRollbackOnEvents",
         "deployment_config": "deploymentConfig",
@@ -437,10 +397,11 @@ class EcsDeploymentGroupProps:
         prod_traffic_listener: "TrafficListener",
         target_groups: typing.Sequence[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroup],
         test_traffic_listener: "TrafficListener",
+        application: typing.Optional[aws_cdk.aws_codedeploy.IEcsApplication] = None,
         application_name: typing.Optional[builtins.str] = None,
         auto_rollback_on_events: typing.Optional[typing.Sequence["RollbackEvent"]] = None,
         deployment_config: typing.Optional["IEcsDeploymentConfig"] = None,
-        termination_wait_time: typing.Optional[aws_cdk.core.Duration] = None,
+        termination_wait_time: typing.Optional[aws_cdk.Duration] = None,
     ) -> None:
         '''
         :param deployment_group_name: -
@@ -448,7 +409,8 @@ class EcsDeploymentGroupProps:
         :param prod_traffic_listener: -
         :param target_groups: -
         :param test_traffic_listener: -
-        :param application_name: -
+        :param application: The CodeDeploy Application to associate to the DeploymentGroup. Default: - create a new CodeDeploy Application.
+        :param application_name: (deprecated) The name to use for the implicitly created CodeDeploy Application. Default: - uses auto-generated name
         :param auto_rollback_on_events: The event type or types that trigger a rollback.
         :param deployment_config: -
         :param termination_wait_time: the number of minutes before deleting the original (blue) task set. During an Amazon ECS deployment, CodeDeploy shifts traffic from the original (blue) task set to a replacement (green) task set. The maximum setting is 2880 minutes (2 days). Default: 60 minutes
@@ -464,6 +426,8 @@ class EcsDeploymentGroupProps:
             "target_groups": target_groups,
             "test_traffic_listener": test_traffic_listener,
         }
+        if application is not None:
+            self._values["application"] = application
         if application_name is not None:
             self._values["application_name"] = application_name
         if auto_rollback_on_events is not None:
@@ -505,8 +469,25 @@ class EcsDeploymentGroupProps:
         assert result is not None, "Required property 'test_traffic_listener' is missing"
         return typing.cast("TrafficListener", result)
 
+    @builtins.property
+    def application(self) -> typing.Optional[aws_cdk.aws_codedeploy.IEcsApplication]:
+        '''The CodeDeploy Application to associate to the DeploymentGroup.
+
+        :default: - create a new CodeDeploy Application.
+        '''
+        result = self._values.get("application")
+        return typing.cast(typing.Optional[aws_cdk.aws_codedeploy.IEcsApplication], result)
+
     @builtins.property
     def application_name(self) -> typing.Optional[builtins.str]:
+        '''(deprecated) The name to use for the implicitly created CodeDeploy Application.
+
+        :default: - uses auto-generated name
+
+        :deprecated: Use {@link application} instead to create a custom CodeDeploy Application.
+
+        :stability: deprecated
+        '''
         result = self._values.get("application_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -522,7 +503,7 @@ class EcsDeploymentGroupProps:
         return typing.cast(typing.Optional["IEcsDeploymentConfig"], result)
 
     @builtins.property
-    def termination_wait_time(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def termination_wait_time(self) -> typing.Optional[aws_cdk.Duration]:
         '''the number of minutes before deleting the original (blue) task set.
 
         During an Amazon ECS deployment, CodeDeploy shifts traffic from the
@@ -533,7 +514,7 @@ class EcsDeploymentGroupProps:
         :default: 60 minutes
         '''
         result = self._values.get("termination_wait_time")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -580,7 +561,7 @@ class EcsServiceProps:
         circuit_breaker: typing.Optional[aws_cdk.aws_ecs.DeploymentCircuitBreaker] = None,
         container_port: typing.Optional[jsii.Number] = None,
         desired_count: typing.Optional[jsii.Number] = None,
-        health_check_grace_period: typing.Optional[aws_cdk.core.Duration] = None,
+        health_check_grace_period: typing.Optional[aws_cdk.Duration] = None,
         launch_type: typing.Optional[aws_cdk.aws_ecs.LaunchType] = None,
         max_healthy_percent: typing.Optional[jsii.Number] = None,
         min_healthy_percent: typing.Optional[jsii.Number] = None,
@@ -690,13 +671,13 @@ class EcsServiceProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def health_check_grace_period(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def health_check_grace_period(self) -> typing.Optional[aws_cdk.Duration]:
         '''The period of time, in seconds, that the Amazon ECS service scheduler ignores unhealthy Elastic Load Balancing target health checks after a task has first started.
 
         :default: - defaults to 60 seconds if at least one load balancer is in-use and it is not already set
         '''
         result = self._values.get("health_check_grace_period")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     @builtins.property
     def launch_type(self) -> typing.Optional[aws_cdk.aws_ecs.LaunchType]:
@@ -853,7 +834,7 @@ typing.cast(typing.Any, IEcsDeploymentConfig).__jsii_proxy_class__ = lambda : _I
 @jsii.interface(
     jsii_type="@cloudcomponents/cdk-blue-green-container-deployment.IEcsDeploymentGroup"
 )
-class IEcsDeploymentGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
+class IEcsDeploymentGroup(aws_cdk.IResource, typing_extensions.Protocol):
     '''Interface for an ECS deployment group.'''
 
     @builtins.property # type: ignore[misc]
@@ -882,7 +863,7 @@ class IEcsDeploymentGroup(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IEcsDeploymentGroupProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.IResource) # type: ignore[misc]
 ):
     '''Interface for an ECS deployment group.'''
 
@@ -963,7 +944,7 @@ class PushImageProject(
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         image_repository: aws_cdk.aws_ecr.IRepository,
@@ -1151,15 +1132,15 @@ class TrafficListener:
         )
 
 
-@jsii.implements(IDummyTaskDefinition, aws_cdk.core.ITaggable)
+@jsii.implements(IDummyTaskDefinition, aws_cdk.ITaggable)
 class DummyTaskDefinition(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-blue-green-container-deployment.DummyTaskDefinition",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         image: builtins.str,
@@ -1217,9 +1198,9 @@ class DummyTaskDefinition(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> aws_cdk.TagManager:
         '''TagManager to set, remove and format tags.'''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(aws_cdk.TagManager, jsii.get(self, "tags"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="taskDefinitionArn")
@@ -1229,18 +1210,18 @@ class DummyTaskDefinition(
 
 @jsii.implements(IEcsDeploymentConfig)
 class EcsDeploymentConfig(
-    aws_cdk.core.Resource,
+    aws_cdk.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-blue-green-container-deployment.EcsDeploymentConfig",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         deployment_config_name: typing.Optional[builtins.str] = None,
-        minimum_healthy_hosts: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.core.IResolvable]] = None,
-        traffic_routing_config: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty]] = None,
+        minimum_healthy_hosts: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.MinimumHealthyHostsProperty, aws_cdk.IResolvable]] = None,
+        traffic_routing_config: typing.Optional[typing.Union[aws_cdk.aws_codedeploy.CfnDeploymentConfig.TrafficRoutingConfigProperty, aws_cdk.IResolvable]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1261,7 +1242,7 @@ class EcsDeploymentConfig(
     @builtins.classmethod
     def from_ecs_deployment_config_name(
         cls,
-        _scope: aws_cdk.core.Construct,
+        _scope: constructs.Construct,
         _id: builtins.str,
         ecs_deployment_config_name: builtins.str,
     ) -> IEcsDeploymentConfig:
@@ -1311,15 +1292,15 @@ class EcsDeploymentConfig(
         return typing.cast(builtins.str, jsii.get(self, "deploymentConfigName"))
 
 
-@jsii.implements(IEcsDeploymentGroup, aws_cdk.core.ITaggable)
+@jsii.implements(IEcsDeploymentGroup, aws_cdk.ITaggable)
 class EcsDeploymentGroup(
-    aws_cdk.core.Resource,
+    aws_cdk.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-blue-green-container-deployment.EcsDeploymentGroup",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         deployment_group_name: builtins.str,
@@ -1327,10 +1308,11 @@ class EcsDeploymentGroup(
         prod_traffic_listener: TrafficListener,
         target_groups: typing.Sequence[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroup],
         test_traffic_listener: TrafficListener,
+        application: typing.Optional[aws_cdk.aws_codedeploy.IEcsApplication] = None,
         application_name: typing.Optional[builtins.str] = None,
         auto_rollback_on_events: typing.Optional[typing.Sequence[RollbackEvent]] = None,
         deployment_config: typing.Optional[IEcsDeploymentConfig] = None,
-        termination_wait_time: typing.Optional[aws_cdk.core.Duration] = None,
+        termination_wait_time: typing.Optional[aws_cdk.Duration] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1340,7 +1322,8 @@ class EcsDeploymentGroup(
         :param prod_traffic_listener: -
         :param target_groups: -
         :param test_traffic_listener: -
-        :param application_name: -
+        :param application: The CodeDeploy Application to associate to the DeploymentGroup. Default: - create a new CodeDeploy Application.
+        :param application_name: (deprecated) The name to use for the implicitly created CodeDeploy Application. Default: - uses auto-generated name
         :param auto_rollback_on_events: The event type or types that trigger a rollback.
         :param deployment_config: -
         :param termination_wait_time: the number of minutes before deleting the original (blue) task set. During an Amazon ECS deployment, CodeDeploy shifts traffic from the original (blue) task set to a replacement (green) task set. The maximum setting is 2880 minutes (2 days). Default: 60 minutes
@@ -1351,6 +1334,7 @@ class EcsDeploymentGroup(
             prod_traffic_listener=prod_traffic_listener,
             target_groups=target_groups,
             test_traffic_listener=test_traffic_listener,
+            application=application,
             application_name=application_name,
             auto_rollback_on_events=auto_rollback_on_events,
             deployment_config=deployment_config,
@@ -1385,20 +1369,20 @@ class EcsDeploymentGroup(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> aws_cdk.TagManager:
         '''TagManager to set, remove and format tags.'''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(aws_cdk.TagManager, jsii.get(self, "tags"))
 
 
-@jsii.implements(aws_cdk.aws_ec2.IConnectable, IEcsService, aws_cdk.core.ITaggable)
+@jsii.implements(aws_cdk.aws_ec2.IConnectable, IEcsService, aws_cdk.ITaggable)
 class EcsService(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-blue-green-container-deployment.EcsService",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         cluster: aws_cdk.aws_ecs.ICluster,
@@ -1409,7 +1393,7 @@ class EcsService(
         circuit_breaker: typing.Optional[aws_cdk.aws_ecs.DeploymentCircuitBreaker] = None,
         container_port: typing.Optional[jsii.Number] = None,
         desired_count: typing.Optional[jsii.Number] = None,
-        health_check_grace_period: typing.Optional[aws_cdk.core.Duration] = None,
+        health_check_grace_period: typing.Optional[aws_cdk.Duration] = None,
         launch_type: typing.Optional[aws_cdk.aws_ecs.LaunchType] = None,
         max_healthy_percent: typing.Optional[jsii.Number] = None,
         min_healthy_percent: typing.Optional[jsii.Number] = None,
@@ -1474,9 +1458,9 @@ class EcsService(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
+    def tags(self) -> aws_cdk.TagManager:
         '''TagManager to set, remove and format tags.'''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+        return typing.cast(aws_cdk.TagManager, jsii.get(self, "tags"))
 
 
 __all__ = [
